@@ -46,7 +46,7 @@ doubling the child's number and adding one.
 use strict;
 use warnings;
 
-our $VERSION = '0.0.4';
+our $VERSION = '0.0.5';
 
 require Exporter;
 our @ISA = qw[Exporter];
@@ -64,6 +64,10 @@ my $PositiveInt = declare
   where     {  $_ > 0  },
   inline_as { "$_ =~ /^[0-9]+\$/ and $_ > 0" };
 
+use overload
+  '""' => sub { $_[0]->ahnentafel },
+  fallback => 1;
+
 =head1 FUNCTIONS
 
 This module exports one function.
@@ -99,10 +103,8 @@ the genders male and female. By default, they are the strings "Male" and
 =cut
 
 class_has genders => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => ArrayRef[Str],
-  lazy    => 1,
-  builder => '_build_genders',
 );
 
 sub _build_genders {
@@ -121,10 +123,8 @@ names like "Grandfather" and "Great Grandmother".
 =cut
 
 class_has parent_names => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => ArrayRef[Str],
-  lazy    => 1,
-  builder => '_build_parent_names',
 );
 
 sub _build_parent_names {
@@ -160,10 +160,8 @@ an odd Ahnentafel are women.
 =cut
 
 has gender => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => Str,
-  lazy    => 1,
-  builder => '_build_gender',
 );
 
 sub _build_gender {
@@ -184,10 +182,8 @@ as appropriate for everyone else.
 =cut
 
 has gender_description => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => Str,
-  lazy    => 1,
-  builder => '_build_gender_description',
 );
 
 sub _build_gender_description {
@@ -205,10 +201,8 @@ generation 1. People 2 and 3 (the parents) are in generation 2. People
 =cut
 
 has generation => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => $PositiveInt,
-  lazy    => 1,
-  builder => '_build_generation',
 );
 
 sub _build_generation {
@@ -227,10 +221,8 @@ of "Great" - "Great Grandmother", "Great Great Grandfather", etc.
 =cut
 
 has description => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => Str,
-  lazy    => 1,
-  builder => '_build_description',
 );
 
 sub _build_description {
@@ -256,10 +248,8 @@ between (and including) the root person and the current person.
 =cut
 
 has ancestry => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => ArrayRef,
-  lazy    => 1,
-  builder => '_build_ancestry',
 );
 
 sub _build_ancestry {
@@ -281,10 +271,8 @@ A string representation of ancestry.
 =cut
 
 has ancestry_string => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => Str,
-  lazy    => 1,
-  builder => '_build_ancestry_string',
 );
 
 sub _build_ancestry_string {
@@ -299,9 +287,7 @@ person.
 =cut
 
 has father => (
-  is      => 'ro',
-  lazy    => 1,
-  builder => '_build_father',
+  is      => 'lazy',
 );
 
 sub _build_father {
@@ -316,9 +302,7 @@ person.
 =cut
 
 has mother => (
-  is      => 'ro',
-  lazy    => 1,
-  builder => '_build_mother',
+  is      => 'lazy',
 );
 
 sub _build_mother {
@@ -332,27 +316,23 @@ The lowest Ahnentafel number that appears in the current generation.
 =cut
 
 has first_in_generation => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => Int,
-  lazy    => 1,
-  builder => '_build_first_in_generation',
 );
 
 sub _build_first_in_generation {
   return 2 ** ($_[0]->generation - 1);
 }
 
-=head is_first_in_generation
+=head2 is_first_in_generation
 
 Is this the first Ahnentafel number in the current generation?
 
 =cut
 
 has is_first_in_generation => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => Bool,
-  lazy    => 1,
-  builder => '_build_is_first_in_generation',
 );
 
 sub _build_is_first_in_generation {
@@ -366,27 +346,23 @@ The highest Ahnentafel number that appears in the current generation.
 =cut
 
 has last_in_generation => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => Int,
-  lazy    => 1,
-  builder => '_build_last_in_generation',
 );
 
 sub _build_last_in_generation {
   return 2 ** $_[0]->generation - 1;
 }
 
-=head is_last_in_generation
+=head2 is_last_in_generation
 
 Is this the last Ahnentafel number in the current generation?
 
 =cut
 
 has is_last_in_generation => (
-  is      => 'ro',
+  is      => 'lazy',
   isa     => Bool,
-  lazy    => 1,
-  builder => '_build_is_last_in_generation',
 );
 
 sub _build_is_last_in_generation {
